summaryrefslogtreecommitdiffstats
path: root/lib/sendf.h
diff options
context:
space:
mode:
authorCurl Upstream <curl-library@lists.haxx.se>2024-05-22 05:54:25 (GMT)
committerBrad King <brad.king@kitware.com>2024-05-29 17:59:48 (GMT)
commit9f46cdb65da8f66c9894ff55ab59ebe8a4058538 (patch)
tree6f346296943bf34983abe2ff91206d581ed850d0 /lib/sendf.h
parente17d8d0c3b8f820bd108b8d66ace3692c81bbf42 (diff)
downloadCMake-9f46cdb65da8f66c9894ff55ab59ebe8a4058538.zip
CMake-9f46cdb65da8f66c9894ff55ab59ebe8a4058538.tar.gz
CMake-9f46cdb65da8f66c9894ff55ab59ebe8a4058538.tar.bz2
curl 2024-05-22 (fd567d4f)
Code extracted from: https://github.com/curl/curl.git at commit fd567d4f06857f4fc8e2f64ea727b1318f76ad33 (curl-8_8_0).
Diffstat (limited to 'lib/sendf.h')
-rw-r--r--lib/sendf.h16
1 files changed, 13 insertions, 3 deletions
diff --git a/lib/sendf.h b/lib/sendf.h
index d736ce4..82a2902 100644
--- a/lib/sendf.h
+++ b/lib/sendf.h
@@ -181,6 +181,16 @@ CURLcode Curl_cwriter_write(struct Curl_easy *data,
const char *buf, size_t nbytes);
/**
+ * Return TRUE iff client writer is paused.
+ */
+bool Curl_cwriter_is_paused(struct Curl_easy *data);
+
+/**
+ * Unpause client writer and flush any buffered date to the client.
+ */
+CURLcode Curl_cwriter_unpause(struct Curl_easy *data);
+
+/**
* Default implementations for do_init, do_write, do_close that
* do nothing and pass the data through.
*/
@@ -302,7 +312,7 @@ CURLcode Curl_creader_set(struct Curl_easy *data, struct Curl_creader *r);
/**
* Read at most `blen` bytes at `buf` from the client.
* @param date the transfer to read client bytes for
* @param buf the memory location to read to
* @param blen the amount of memory at `buf`
* @param nread on return the number of bytes read into `buf`
@@ -350,8 +360,8 @@ curl_off_t Curl_creader_client_length(struct Curl_easy *data);
* Ask the installed reader at phase CURL_CR_CLIENT to start
* reading from the given offset. On success, this will reduce
* the `total_length()` by the amount.
* @param date the transfer to read client bytes for
* param offset the offset where to start reads from, negative
* values will be ignored.
* @return CURLE_OK if offset could be set
* CURLE_READ_ERROR if not supported by reader or seek/read failed
@@ -302,7 +312,7 @@ CURLcode Curl_creader_set(struct Curl_easy *data, struct Curl_creader *r);
/**
* Read at most `blen` bytes at `buf` from the client.
- * @param date the transfer to read client bytes for
+ * @param data the transfer to read client bytes for
* @param buf the memory location to read to
* @param blen the amount of memory at `buf`
@@ -350,8 +360,8 @@ curl_off_t Curl_creader_client_length(struct Curl_easy *data);
* reading from the given offset. On success, this will reduce
* the `total_length()` by the amount.
- * @param date the transfer to read client bytes for
- * param offset the offset where to start reads from, negative
+ * @param data the transfer to read client bytes for
+ * @param offset the offset where to start reads from, negative
* values will be ignored.
* @return CURLE_OK if offset could be set